@@ -4,11 +4,11 @@ from __future__ import unicode_literals
 
 import django
 
-__author__ = 'Dmitriy Sokolov'
-__version__ = '0.8.4'
+__author__ = "Dmitriy Sokolov"
+__version__ = "0.10.0"
 
 if django.VERSION < (3, 2):
-    default_app_config = 'rangefilter.apps.RangeFilterConfig'
+    default_app_config = "rangefilter.apps.RangeFilterConfig"
 
 
 VERSION = __version__
